<?php
/**
 * Horde Log package
 *
 * This package is based on Zend_Log from the Zend Framework
 * (http://framework.zend.com).  Both that package and this
 * one were written by Mike Naberezny and Chuck Hagenbuch.
 *
 * @package  Horde::Log
 * @author   Mike Naberezny (mike@maintainable.com)
 * @author   Chuck Hagenbuch (chuck@horde.org)
 * @license  http://opensource.org/licenses/bsd-license.php BSD
 */

namespace Horde::Log;

import Horde::Log::Exception;

/**
 * @package  Horde::Log
 * @author   Mike Naberezny (mike@maintainable.com)
 * @author   Chuck Hagenbuch (chuck@horde.org)
 * @license  http://opensource.org/licenses/bsd-license.php BSD
 */
class Filter_Level implements Filter_Interface
{
    /**
     * @var integer
     */
    protected $_level;

    /**
     * Filter out any log messages greater than $level.
     *
     * @param  integer  $level  Maximum log level to pass through the filter
     */
    public function __construct($level)
    {
        if (! is_integer($level)) {
            throw new Exception('Level must be an integer');
        }

        $this->_level = $level;
    }

    /**
     * Returns TRUE to accept the message, FALSE to block it.
     *
     * @param  string   $message  message for the log
     * @param  integer  $level    log level
     * @return boolean            accepted?
     */
    public function accept($message, $level)
    {
        return $level <= $this->_level;
    }

}
