<?php
/**
 * Horde Log package
 *
 * This package is based on Zend_Log from the Zend Framework
 * (http://framework.zend.com).  Both that package and this
 * one were written by Mike Naberezny and Chuck Hagenbuch.
 *
 * @category Horde
 * @package  Horde::Log
 * @subpackage Filters
 * @author   Mike Naberezny (mike@maintainable.com)
 * @author   Chuck Hagenbuch (chuck@horde.org)
 * @license  http://opensource.org/licenses/bsd-license.php BSD
 */

namespace Horde::Log;

import Horde::Log::Exception;

/**
 * @category Horde
 * @package  Horde::Log
 * @subpackage Filters
 * @author   Mike Naberezny (mike@maintainable.com)
 * @author   Chuck Hagenbuch (chuck@horde.org)
 * @license  http://opensource.org/licenses/bsd-license.php BSD
 */
class Filter_Message implements Filter_Interface
{
    /**
     * @var string
     */
    protected $_regexp;

    /**
     * Filter out any log messages not matching $regexp.
     *
     * @param  string  $regexp     Regular expression to test the log message
     * @throws Horde::Log::Exception  Invalid regular expression
     */
    public function __construct($regexp)
    {
        if (@preg_match($regexp, '') === false) {
            throw new Exception("Invalid regular expression '$regexp'");
        }
        $this->_regexp = $regexp;
    }

    /**
     * Returns TRUE to accept the message, FALSE to block it.
     *
     * @param  string   $message  message for the log
     * @param  integer  $level    log level
     * @return boolean            accepted?
     */
    public function accept($message, $level)
    {
        return preg_match($this->_regexp, $message) > 0;
    }

}
