<?php
/**
 * Horde Log package
 *
 * This package is based on Zend_Log from the Zend Framework
 * (http://framework.zend.com).  Both that package and this
 * one were written by Mike Naberezny and Chuck Hagenbuch.
 *
 * @category Horde
 * @package  Horde::Log
 * @subpackage Formatters
 * @author   Mike Naberezny (mike@maintainable.com)
 * @author   Chuck Hagenbuch (chuck@horde.org)
 * @license  http://opensource.org/licenses/bsd-license.php BSD
 */

namespace Horde::Log;

import Horde::Log::Exception;

/**
 * @category Horde
 * @package  Horde::Log
 * @subpackage Formatters
 * @author   Mike Naberezny (mike@maintainable.com)
 * @author   Chuck Hagenbuch (chuck@horde.org)
 * @license  http://opensource.org/licenses/bsd-license.php BSD
 */
class Formatter_Simple
{
    protected $_format;

    public function __construct($format = null)
    {
        if ($format === null) {
            $format = '%timestamp% %level%: %message%' . PHP_EOL;
        }

        if (!is_string($format)) {
            throw new Exception('Format must be a string');
        }

        $this->_format = $format;
    }

    /**
     * Formats a message to be written by the handler.
     *
     * @param  string   $message  message for the log
     * @param  integer  $level    log level
     * @return string             formatted message
     */
    public function format($message, $level)
    {
        return str_replace(array('%message%', '%level%', '%timestamp%'),
                           array($message, $level, date('c')),
                           $this->_format);
    }

}
