<?php
/**
 * Horde Log package
 *
 * This package is based on Zend_Log from the Zend Framework
 * (http://framework.zend.com).  Both that package and this
 * one were written by Mike Naberezny and Chuck Hagenbuch.
 *
 * @category Horde
 * @package  Horde::Log
 * @subpackage Handlers
 * @author   Mike Naberezny (mike@maintainable.com)
 * @author   Chuck Hagenbuch (chuck@horde.org)
 * @license  http://opensource.org/licenses/bsd-license.php BSD
 */

namespace Horde::Log;

/**
 * @category Horde
 * @package  Horde::Log
 * @subpackage Handlers
 * @author   Mike Naberezny (mike@maintainable.com)
 * @author   Chuck Hagenbuch (chuck@horde.org)
 * @license  http://opensource.org/licenses/bsd-license.php BSD
 */
class Handler_Db extends Handler_Abstract
{
    /**
     * Database adapter instance
     * @var Horde_Db_Adapter
     */
    private $_db;

    /**
     * Name of the log table in the database
     * @var string
     */
    private $_table;

    /**
     * Options to be set by setOption().  Sets the field names in the database table.
     *
     * @var array
     */
    protected $_options = array('fieldMessage'  => 'message',
                                'fieldLevel'    => 'level');

    /**
     * Class constructor
     *
     * @param Horde_Db_Adapter $db   Database adapter instance
     * @param string $table         Log table in database
     */
    public function __construct($db, $table)
    {
        $this->_db    = $db;
        $this->_table = $table;
    }

    /**
     * Write a message to the log.
     *
     * @param  $message    Log message
     * @param  $level      Log level, one of Horde::Log::LEVEL_* constants
     * @return bool        Always True
     */
    public function write($message, $level)
    {
        $fields = array($this->_options['fieldMessage'] => $message,
                        $this->_options['fieldLevel']   => $level);

        $this->_db->insert($this->_table, $fields);
        return true;
    }

}
