<?php
/**
 * Horde Log package
 *
 * This package is based on Zend_Log from the Zend Framework
 * (http://framework.zend.com).  Both that package and this
 * one were written by Mike Naberezny and Chuck Hagenbuch.
 *
 * @category Horde
 * @package  Horde::Log
 * @subpackage Handlers
 * @author   Mike Naberezny (mike@maintainable.com)
 * @author   Chuck Hagenbuch (chuck@horde.org)
 * @license  http://opensource.org/licenses/bsd-license.php BSD
 */

namespace Horde::Log;

import Horde::Log::Exception;
import Horde::Log::Filter_Simple;

/**
 * @category Horde
 * @package  Horde::Log
 * @subpackage Handlers
 * @author   Mike Naberezny (mike@maintainable.com)
 * @author   Chuck Hagenbuch (chuck@horde.org)
 * @license  http://opensource.org/licenses/bsd-license.php BSD
 */
class Handler_Stream extends Handler_Abstract
{
    /**
     * Formats the log message before writing.
     * @var Horde::Log::Formatter_Interface
     */
    protected $_formatter;

    /**
     * Holds the PHP stream to log to.
     * @var null|stream
     */
    protected $_stream = null;


    /**
     * Class Constructor
     *
     * @param  streamOrUrl     Stream or URL to open as a stream
     * @param  mode            Mode, only applicable if a URL is given
     */
    public function __construct($streamOrUrl, $mode = 'a+')
    {
        $this->_formatter = new Formatter_Simple();

        if (is_resource($streamOrUrl)) {
            if (get_resource_type($streamOrUrl) != 'stream') {
                throw new Exception('Resource is not a stream');
            }

            if ($mode != 'a+') {
                throw new Exception('Mode cannot be changed on existing streams');
            }

            $this->_stream = $streamOrUrl;
        } else {
            if (! $this->_stream = @fopen($streamOrUrl, $mode, false)) {
                $msg = "\"$streamOrUrl\" cannot be opened with mode \"$mode\"";
                throw new Exception($msg);
            }
        }
    }

    /**
     * Write a message to the log.  This function really just writes the message to the buffer.
     * If buffering is enabled, the message won't hit the filesystem until the buffer fills
     * or is flushed.  If buffering is not enabled, the buffer will be flushed immediately.
     *
     * @param  $message    Log message
     * @param  $level      Log level, one of Horde::Log::LEVEL_* constants
     * @return bool        True
     */
    public function write($message, $level)
    {
        $line = $this->_formatter->format($message, $level);

        if (! @fwrite($this->_stream, $line)) {
            throw new Exception("Unable to write to stream");
        }

        return true;
    }

}
